Gestione tornei — SoL 3, manuale utente

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »
- Anagrafiche di base »

# Gestione tornei

Il torneo è chiaramente l’elemento primario di tutto il sistema, tutto quanto verte a permettere di gestire in maniera facile e veloce questi eventi.

## Voci del menu

Oltre alle azioni standard il menu contiene queste voci:

Gestione tornei

Dettagli
  Mostra la gestione del torneo selezionato.
Concorrenti
  Consente di correggere i concorrenti di un torneo già svolto.
Rigioca di nuovo
  Consente di duplicare un torneo: particolarmente utile nei tornei di doppio o a squadre: in pratica replica il torneo sul giorno corrente, con tutti i suoi concorrenti; assicurati di aggiornarne la descrizione ed eventualmente la data dell’evento!
Scarica
  Permette di scaricare i dati del torneo.

## Inserimento e modifica

Ogni torneo ha una data e una descrizione dell’evento e non ci possono essere due distinti tornei nella stessa data associati al medesimo campionato.

Il posto è opzionale.

Durata e preavviso si riferiscono alla durata di un singolo turno e sono espressi in minuti. Vengono usati per visualizzare l’L’orologio con allarme..

Un torneo può essere associato a una particolare valutazione: in questo caso il primo turno verrà generato tenendo conto del valore di ciascun giocatore invece che usando un ordine casuale.

Il metodo accoppiamenti determina come verranno create le coppie di avversari ad ogni nuovo turno:

`Classifica`
  l’algoritmo `serial` cercherà di accoppiare un giocatore con uno di quelli che lo seguono nella classifica corrente, ad esempio il primo col secondo, il terzo con il quarto e così via;
`Classifica sfasata`
  per ritardare per quanto possibile gli incontri tra le teste di serie, questo metodo (`dazed`) usa un sistema più elaborato: prende i giocatori a pari punti di quello che sta esaminando e cerca di accoppiare il primo con quello che sta a metà di questa serie, il secondo con quello a metà+1, e così via.

Lo score fantasma è il punteggio assegnato al giocatore negli incontri con il fantasma, quando il numero di concorrenti è dispari. Per convenzione questi incontri assegnano uno score pari a 25 al giocatore ma ci possono essere casi in cui sia preferibile un punteggio diverso, ad esempio quando il numero di concorrenti è molto basso e il vincere 25—0 darebbe un vantaggio inappropriato ai giocatori più deboli.

Il responsabile generalmente indica l’utente che ha inserito quel particolare torneo: i dati del torneo potranno essere modificati solo da lui (oltre che dall’amministratore del sistema.).

- Gestione torneo
  - Concorrenti
  - Primo turno
  - Incontri
  - Classifica
- Correzione concorrenti

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »
- Anagrafiche di base »